@@ -3,7 +3,7 @@ package App::CekBpom;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2020-09-09'; # DATE
 our $DIST = 'App-CekBpom'; # DIST
-our $VERSION = '0.004'; # VERSION
+our $VERSION = '0.005'; # VERSION
 
 use 5.010001;
 use strict;
@@ -40,6 +40,7 @@ HTTP client behavior by setting `LWP_USERAGENT_PLUGINS` environment variable.
 _
     args => {
         search_type => {
+            summary => 'Select what field to search against',
             schema => ['str*', in=>[sort keys %search_types]],
             default => 'nama_produk',
             cmdline_aliases => {
@@ -137,6 +138,8 @@ sub cek_bpom {
     if (@rows < $num_results) {
         # XXX should've been a fatal error
         log_warn "Some results cannot be parsed (only got %d out of %d)", scalar(@rows), $num_results;
+    } else {
+        log_trace "Got $num_results result(s)";
     }
 
     my %resmeta;
@@ -160,7 +163,7 @@ App::CekBpom - Check BPOM products via the command-line (CLI interface for cekbp
 
 =head1 VERSION
 
-This document describes version 0.004 of App::CekBpom (from Perl distribution App-CekBpom), released on 2020-09-09.
+This document describes version 0.005 of App::CekBpom (from Perl distribution App-CekBpom), released on 2020-09-09.
 
 =head1 DESCRIPTION
 
@@ -190,6 +193,8 @@ Arguments ('*' denotes required arguments):
 
 =item * B<search_type> => I<str> (default: "nama_produk")
 
+Select what field to search against.
+
 
 =back
 
